Important Differences between Celery and Girder Worker
******************************************************

.. note:: TODO - Work through celery documentation and note important differences between Girder Worker and Celery docs
